@@ -2,7 +2,7 @@
 
 /*
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
- *   Copyright (c) 2013-2017 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
+ *   Copyright (c) 2013-2018 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
  *   The Tcpreplay Suite of tools is free software: you can redistribute it 
  *   and/or modify it under the terms of the GNU General Public License as 
@@ -92,6 +92,7 @@ struct tcpeditdlt_plugin_s {
     tcpeditdlt_l2addr_type_t (*plugin_l2addr_type)(void);
     u_char *(*plugin_get_mac)(tcpeditdlt_t *, tcpeditdlt_mac_type_t, const u_char *, const int);
     void *config; /* user configuration data for the encoder */
+    size_t config_size;
 };
 
 
@@ -126,6 +127,7 @@ struct tcpeditdlt_s {
     int l2len;                              /* set by decoder and updated by encoder */
     u_int16_t proto;                        /* layer 3 proto type?? */
     void *decoded_extra;                    /* any extra L2 data from decoder like VLAN tags */
+    size_t decoded_extra_size;              /* size of decode_extra buffer */
     u_char srcmac[MAX_MAC_LEN];             /* buffers to store the src & dst MAC */
     u_char dstmac[MAX_MAC_LEN];
 };
