@@ -2,7 +2,7 @@
 
 /*
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
- *   Copyright (c) 2013-2017 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
+ *   Copyright (c) 2013-2018 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
  *   The Tcpreplay Suite of tools is free software: you can redistribute it 
  *   and/or modify it under the terms of the GNU General Public License as 
@@ -33,6 +33,7 @@
 
 #include "tcpreplay.h"
 #include "tcpreplay_api.h"
+#include "timestamp_trace.h"
 
 #ifdef TCPREPLAY_EDIT
 #include "tcpreplay_edit_opts.h"
@@ -60,7 +61,6 @@ main(int argc, char *argv[])
 {
     int i, optct = 0;
     int rcode;
-    char buf[1024];
 
     fflush(NULL);
 
@@ -146,6 +146,8 @@ main(int argc, char *argv[])
     }
 
     if (ctx->stats.bytes_sent > 0) {
+        char buf[1024];
+
         packet_stats(&ctx->stats);
         if (ctx->options->flow_stats)
             flow_stats(ctx);
@@ -156,7 +158,13 @@ main(int argc, char *argv[])
             printf("%s", buf);
         }
     }
+
+#ifdef TIMESTAMP_TRACE
+    dump_timestamp_trace_array(&ctx->stats.start_time, &ctx->stats.end_time,
+            ctx->options->speed.speed);
+#endif
     tcpreplay_close(ctx);
+    restore_stdin();
     return 0;
 }   /* main() */
 
